@@ -18,11 +18,11 @@ Struct::Path::PerlStyle - Perl-style syntax frontend for L<Struct::Path|Struct::
 
 =head1 VERSION
 
-Version 0.60
+Version 0.61
 
 =cut
 
-our $VERSION = '0.60';
+our $VERSION = '0.61';
 
 =head1 SYNOPSIS
 
@@ -66,8 +66,9 @@ Parse perl-style string to L<Struct::Path|Struct::Path> path
 
 our $FILTERS = {
     '<<' => sub { # step back $count times
-        my $count = defined $_[0] ? $_[0] : 1;
+        my $static = defined $_[0] ? $_[0] : 1;
         return sub {
+            my $count = $static; # keep arg (reusable closure)
             while ($count) {
                 croak "Can't step back (root of the structure)"
                     unless (@{$_[0]} and @{$_[1]});
@@ -86,12 +87,11 @@ our $FILTERS = {
         croak "Only one arg accepted by 'eq'" if (@_ != 1);
         my $arg = shift;
         return sub {
-            return ${$_[1]->[-1]} eq $arg ? 1 : 0;
+            return (defined ${$_[1]->[-1]} and ${$_[1]->[-1]} eq $arg) ? 1 : 0;
         };
     },
 };
 
-
 sub ps_parse($) {
     my $path = shift;
     croak "Undefined path passed" unless (defined $path);
